X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/29c26b88e7333fb8ea022c4bb4277bc0394ab9e3..338c0838580b32f1258a800392d93cf973baf1e6:/dwm.h?ds=sidebyside

diff --git a/dwm.h b/dwm.h
index 2751c9e..d795c84 100644
--- a/dwm.h
+++ b/dwm.h
@@ -41,28 +41,6 @@ enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 
-typedef union {
-	const char *cmd;
-	int i;
-} Arg; /* argument type */
-
-typedef struct {
-	int ascent;
-	int descent;
-	int height;
-	XFontSet set;
-	XFontStruct *xfont;
-} Fnt;
-
-typedef struct {
-	int x, y, w, h;
-	unsigned long norm[ColLast];
-	unsigned long sel[ColLast];
-	Drawable drawable;
-	Fnt font;
-	GC gc;
-} DC; /* draw context */
-
 typedef struct Client Client;
 struct Client {
 	char name[256];
@@ -72,7 +50,7 @@ struct Client {
 	int minax, minay, maxax, maxay;
 	long flags; 
 	unsigned int border;
-	Bool isbanned, isfixed, ismax, isversatile;
+	Bool isbanned, isfixed, ismax, isfloating;
 	Bool *tags;
 	Client *next;
 	Client *prev;
@@ -80,6 +58,21 @@ struct Client {
 	Window win;
 };
 
+typedef struct {
+	int x, y, w, h;
+	unsigned long norm[ColLast];
+	unsigned long sel[ColLast];
+	Drawable drawable;
+	GC gc;
+	struct {
+		int ascent;
+		int descent;
+		int height;
+		XFontSet set;
+		XFontStruct *xfont;
+	} font;
+} DC; /* draw context */
+
 typedef struct {
 	const char *symbol;
 	void (*arrange)(void);
@@ -90,11 +83,10 @@ extern char stext[256];				/* status text */
 extern int screen, sx, sy, sw, sh;		/* screen geometry */
 extern int wax, way, wah, waw;			/* windowarea geometry */
 extern unsigned int bh, blw;			/* bar height, bar layout label width */
-extern unsigned int master, nmaster;		/* master percent, number of master clients */
 extern unsigned int ntags, numlockmask;		/* number of tags, dynamic lock mask */
 extern void (*handler[LASTEvent])(XEvent *);	/* event handler */
 extern Atom wmatom[WMLast], netatom[NetLast];
-extern Bool running, selscreen, *seltag;	/* seltag is array of Bool */
+extern Bool selscreen, *seltag;			/* seltag is array of Bool */
 extern Client *clients, *sel, *stack;		/* global client list and stack */
 extern Cursor cursor[CurLast];
 extern DC dc;					/* global draw context */
@@ -103,40 +95,41 @@ extern Layout *lt;
 extern Window root, barwin;
 
 /* client.c */
+extern void attach(Client *c);			/* attaches c to global client list */
 extern void configure(Client *c);		/* send synthetic configure event */
+extern void detach(Client *c);			/* detaches c from global client list */
 extern void focus(Client *c);			/* focus c, c may be NULL */
-extern void killclient(Arg *arg);		/* kill c nicely */
+extern void killclient(const char *arg);		/* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);	/* manage new client */
 extern void resize(Client *c, int x, int y,
 		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
-extern void toggleversatile(Arg *arg);		/* toggles focused client between versatile/and non-versatile state */
+extern void togglefloating(const char *arg);	/* toggles focused client between floating/tiled state */
 extern void updatesizehints(Client *c);		/* update the size hint variables of c */
 extern void updatetitle(Client *c);		/* update the name of c */
 extern void unmanage(Client *c);		/* destroy c */
-extern void zoom(Arg *arg);			/* zooms the focused client to master area, arg is ignored */
 
 /* draw.c */
 extern void drawstatus(void);			/* draw the bar */
-extern void drawtext(const char *text,
-		unsigned long col[ColLast]);	/* draw text */
+extern void drawtext(const char *text, unsigned long col[ColLast]);	/* draw text */
 extern unsigned int textw(const char *text);	/* return the width of text in px*/
 
 /* event.c */
 extern void grabkeys(void);			/* grab all keys defined in config.h */
 
 /* layout.c */
-extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
-extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
-extern void incnmaster(Arg *arg);		/* increments nmaster with arg's index value */
+extern void floating(void);			/* arranges all windows floating */
+extern void focusclient(const char *arg);	/* focuses next(1)/previous(-1) visible client */
+extern void incmasterw(const char *arg);	/* increments the master width with arg's index value */
+extern void incnmaster(const char *arg);	/* increments nmaster with arg's index value */
 extern void initlayouts(void);			/* initialize layout array */
 extern Client *nexttiled(Client *c);		/* returns tiled successor of c */
-extern void resizemaster(Arg *arg);		/* resizes the master percent with arg's index value */
 extern void restack(void);			/* restores z layers of all clients */
-extern void setlayout(Arg *arg);		/* sets layout, -1 toggles */
-extern void versatile(void);			/* arranges all windows versatile */
+extern void setlayout(const char *arg);		/* sets layout, -1 toggles */
+extern void togglemax(const char *arg);		/* toggles maximization of floating client */
+extern void zoom(const char *arg);		/* zooms the focused client to master area, arg is ignored */
 
 /* main.c */
-extern void quit(Arg *arg);			/* quit dwm nicely */
+extern void quit(const char *arg);		/* quit dwm nicely */
 extern void sendevent(Window w, Atom a, long value);	/* send synthetic event to w */
 extern int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 
@@ -144,13 +137,13 @@ extern int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 extern void compileregs(void);			/* initialize regexps of rules defined in config.h */
 extern Bool isvisible(Client *c);		/* returns True if client is visible */
 extern void settags(Client *c, Client *trans);	/* sets tags of c */
-extern void tag(Arg *arg);			/* tags c with arg's index */
-extern void toggletag(Arg *arg);		/* toggles c tags with arg's index */
-extern void toggleview(Arg *arg);		/* toggles the tag with arg's index (in)visible */
-extern void view(Arg *arg);			/* views the tag with arg's index */
+extern void tag(const char *arg);		/* tags c with arg's index */
+extern void toggletag(const char *arg);		/* toggles c tags with arg's index */
+extern void toggleview(const char *arg);	/* toggles the tag with arg's index (in)visible */
+extern void view(const char *arg);		/* views the tag with arg's index */
 
 /* util.c */
 extern void *emallocz(unsigned int size);	/* allocates zero-initialized memory, exits on error */
 extern void eprint(const char *errstr, ...);	/* prints errstr and exits with 1 */
-extern void spawn(Arg *arg);			/* forks a new subprocess with arg's cmd */
+extern void spawn(const char *arg);		/* forks a new subprocess with arg's cmd */